@@ -6,7 +6,7 @@ use JSON::PP;
 use List::Util qw(sum min max);
 use Scalar::Util qw(looks_like_number);
 
-our $VERSION = '0.78';
+our $VERSION = '0.80';
 
 sub new {
     my ($class, %opts) = @_;
@@ -234,6 +234,30 @@ sub run_query {
             next;
         }
 
+        # support for tail(n)
+        if ($part =~ /^tail\((\d+)\)$/) {
+            my $count = $1;
+            @next_results = map {
+                if (ref $_ eq 'ARRAY') {
+                    my $arr = $_;
+
+                    if ($count == 0 || !@$arr) {
+                        [];
+                    } else {
+                        my $start = @$arr - $count;
+                        $start = 0 if $start < 0;
+
+                        [ @$arr[$start .. $#$arr] ];
+                    }
+                } else {
+                    $_;
+                }
+            } @results;
+
+            @results = @next_results;
+            next;
+        }
+
         # support for chunks(n)
         if ($part =~ /^chunks\((\d+)\)$/) {
             my $size = $1;
@@ -317,6 +341,13 @@ sub run_query {
             next;
         }
 
+        # support for merge_objects()
+        if ($part eq 'merge_objects()' || $part eq 'merge_objects') {
+            @next_results = map { _apply_merge_objects($_) } @results;
+            @results      = @next_results;
+            next;
+        }
+
         # support for add
         if ($part eq 'add') {
             @next_results = map {
@@ -1227,6 +1258,29 @@ sub _apply_to_number {
     return $value;
 }
 
+sub _apply_merge_objects {
+    my ($value) = @_;
+
+    if (ref $value eq 'ARRAY') {
+        my %merged;
+        my $saw_object = 0;
+
+        for my $element (@$value) {
+            next unless ref $element eq 'HASH';
+            %merged = (%merged, %$element);
+            $saw_object = 1;
+        }
+
+        return $saw_object ? \%merged : {};
+    }
+
+    if (ref $value eq 'HASH') {
+        return { %$value };
+    }
+
+    return $value;
+}
+
 sub _traverse {
     my ($data, $query) = @_;
     my @steps = split /\./, $query;
@@ -1899,7 +1953,7 @@ JQ::Lite - A lightweight jq-like JSON query engine in Perl
 
 =head1 VERSION
 
-Version 0.76
+Version 0.79
 
 =head1 SYNOPSIS
 
@@ -1936,9 +1990,9 @@ jq-like syntax — entirely within Perl, with no external binaries or XS modules
 
 =item * Pipe-style query chaining using | operator
 
-=item * Built-in functions: length, keys, values, first, last, reverse, sort, sort_desc, sort_by, min_by, max_by, unique, unique_by, has, contains, group_by, group_count, join, split, count, empty, type, nth, del, compact, upper, lower, titlecase, abs, ceil, floor, trim, substr, slice, startswith, endswith, add, sum, sum_by, avg_by, product, min, max, avg, median, mode, variance, stddev, drop, chunks, flatten_all, flatten_depth, clamp, to_number, pick
+=item * Built-in functions: length, keys, values, first, last, reverse, sort, sort_desc, sort_by, min_by, max_by, unique, unique_by, has, contains, group_by, group_count, join, split, count, empty, type, nth, del, compact, upper, lower, titlecase, abs, ceil, floor, trim, substr, slice, startswith, endswith, add, sum, sum_by, avg_by, product, min, max, avg, median, mode, variance, stddev, drop, tail, chunks, flatten_all, flatten_depth, clamp, to_number, pick, merge_objects
 
-=item * Supports map(...), limit(n), drop(n), and chunks(n) style transformations
+=item * Supports map(...), limit(n), drop(n), tail(n), and chunks(n) style transformations
 
 =item * Interactive mode for exploring queries line-by-line
 
@@ -2058,6 +2112,21 @@ Returns:
   [ { "name": "Alice", "email": "alice\@example.com" },
     { "name": "Bob" } ]
 
+=item * merge_objects()
+
+Merges arrays of objects into a single hash reference using last-write-wins
+semantics. Non-object values within the array are ignored. When no objects are
+found, an empty hash reference is returned. Applying the helper directly to an
+object returns a shallow copy of that object.
+
+Example:
+
+  .items | merge_objects()
+
+Returns:
+
+  { "name": "Widget", "value": 2, "active": true }
+
 =item * empty()
 
 Discards all output. Compatible with jq.
@@ -2250,6 +2319,18 @@ Examples:
   .users | slice(0, 2)        # => first two users
   .users | slice(-2)          # => last two users
 
+=item * tail(n)
+
+Returns the final C<n> elements of the current array. When C<n> is zero the
+result is an empty array, and when C<n> exceeds the array length the entire
+array is returned unchanged. Non-array inputs pass through untouched so the
+helper composes cleanly inside pipelines that also yield scalars or objects.
+
+Examples:
+
+  .users | tail(2)            # => last two users
+  .users | tail(10)           # => full array when shorter than 10
+
 =item * index(value)
 
 Returns the zero-based index of the first occurrence of the supplied value.
